==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimTemplateFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class PersistentVolumeClaimTemplateFluentImpl<A extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<A>{
  public PersistentVolumeClaimTemplateFluentImpl() {
  }
  public PersistentVolumeClaimTemplateFluentImpl(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
  }
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder spec;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec item) {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PersistentVolumeClaimTemplateFluentImpl that = (PersistentVolumeClaimTemplateFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) PersistentVolumeClaimTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class SpecNestedImpl<N> extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<N>> implements io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec item) {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder builder;
    public N and() {
      return (N) PersistentVolumeClaimTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimTemplateFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PersistentVolumeClaimTemplateFluentImpl<A extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<A>{
  public PersistentVolumeClaimTemplateFluentImpl() {
  }
  public PersistentVolumeClaimTemplateFluentImpl(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder spec;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec item) {
    return new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PersistentVolumeClaimTemplateFluentImpl that = (PersistentVolumeClaimTemplateFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) PersistentVolumeClaimTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class SpecNestedImpl<N> extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<N>> implements io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec item) {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder builder;
    public N and() {
      return (N) PersistentVolumeClaimTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
